(model-recipes-index)=

# Model Recipes

Model recipes are tutorials to run Gym with various data recipes that were used to train models.


## Backend Guides

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`server;1.5em;sd-mr-1` Nemotron 3 Nano
:link: model-recipes-nemotron-3-nano
:link-type: ref
Distributed training of Nemotron 3 Nano 30B across multiple nodes using Slurm and Ray.
+++
{bdg-secondary}`model recipe` {bdg-secondary}`nemotron`
:::

:::{grid-item-card} {octicon}`server;1.5em;sd-mr-1` Nemotron 3 Super
:link: model-recipes-nemotron-3-super
:link-type: ref
Distributed training of Nemotron 3 Super 120B across multiple nodes using Slurm and Ray.
+++
{bdg-secondary}`model recipe` {bdg-secondary}`nemotron`
:::

::::
